package com.xinelu.manage.mapper.departmentdiseasetype;

import com.xinelu.manage.domain.departmentdiseasetype.DepartmentDiseaseType;
import com.xinelu.manage.dto.department.DepartmentDTO;
import com.xinelu.manage.dto.departmentdiseasetype.DepartmentDiseaseTypeDto;
import com.xinelu.manage.vo.department.DepartmentVO;
import java.util.List;


/**
 * 科室病种信息Mapper接口
 *
 * @author xinelu
 * @date 2024-02-26
 */
public interface DepartmentDiseaseTypeMapper {
    /**
     * 查询科室病种信息
     *
     * @param id 科室病种信息主键
     * @return 科室病种信息
     */
    DepartmentDiseaseType selectDepartmentDiseaseTypeById(Long id);

    /**
     * 查询科室病种信息列表
     *
     * @param departmentDiseaseType 科室病种信息
     * @return 科室病种信息集合
     */
    List<DepartmentDiseaseType> selectDepartmentDiseaseTypeList(DepartmentDiseaseTypeDto departmentDiseaseType);

    /**
     * 新增科室病种信息
     *
     * @param departmentDiseaseType 科室病种信息
     * @return 结果
     */
    int insertDepartmentDiseaseType(DepartmentDiseaseType departmentDiseaseType);

    /**
     * 修改科室病种信息
     *
     * @param departmentDiseaseType 科室病种信息
     * @return 结果
     */
    int updateDepartmentDiseaseType(DepartmentDiseaseType departmentDiseaseType);

    /**
     * 删除科室病种信息
     *
     * @param id 科室病种信息主键
     * @return 结果
     */
    int deleteDepartmentDiseaseTypeById(Long id);

    /**
     * 批量删除科室病种信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDepartmentDiseaseTypeByIds(Long[] ids);

    /**
     * 科室病种数量
     *
     * @param departmentDto 查询条件
     * @return DepartmentVO
     */
    List<DepartmentVO> selectDiseaseTypeCount(DepartmentDTO departmentDto);
}
